import {scaleSqrt, scaleTime, min, max, extent, timeFormat } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { Marks } from './Marks';
import { config } from './config';

const App = () => {
  const { width, height, csvUrl, countriesJsonUrl} = config;
  const { worldAtlas } = useWorldAtlas(countriesJsonUrl);
  const { data } = useData(csvUrl);

  if (!worldAtlas || !data) {
    return <pre>Loading...</pre>;
  }
  
  const sizeValue = d => d['Total Dead and Missing'];
	const maxRadius = 8;
  const sizeScale = scaleSqrt()
  	.domain([0, max(data, sizeValue)])
  	.range([0, maxRadius]);  
        
  return (
    <svg width={width} height={height}>
				<Marks 
          worldAtlas={worldAtlas} 
          data={data} 
          sizeScale={sizeScale} 
          sizeValue={sizeValue} 
        />
    </svg>
  );
};

export default App;